#ifndef __LIBKYDESKTOPCTRL__H__
#define __LIBKYDESKTOPCTRL__H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdbool.h>

#define EXMLFILE        (500)
#define EJSONFILE       (499)
#define EDBUS           (498)

typedef enum _kdk_deb_bwlist_type {
    DEB_NORMAL = 0,     //未开启黑白名单
    DEB_WHITELIST,      //白名单
    DEB_BLACKLIST,      //黑名单
} kdk_deb_bwlist_type;

typedef struct _kdk_deb_bwlist {
    char **debs;    //包名列表
    int count;      //包信息数量
} kdk_deb_bwlist;

typedef enum _kdk_controlpanel_module {
    CP_SYS = 0,
    CP_SYS_DISPLAY,
    CP_SYS_TOUCHSCREEN,
    CP_SYS_AUTOBOOT,
    CP_SYS_DEFAULTAPP,
    CP_SYS_POWER,

    CP_DT = 16,
    CP_DT_AREA,
    CP_DT_DAT,

    CP_ACNT = 32,
    CP_ACNT_CLOUD,
    CP_ACNT_USERINFO,

    CP_DEV = 48,
    CP_DEV_AUDIO,
    CP_DEV_KEYBOARD,
    CP_DEV_MOUSE,
    CP_DEV_PRINTER,
    CP_DEV_SHORTCUT,
    CP_DEV_TOUCHPAD,

    CP_NET = 64,
    CP_NET_CONNECT,
    CP_NET_PROXY,
    CP_NET_VINO,
    CP_NET_VPN,

    CP_NOTICE = 80,
    CP_NOTICE_ABOUT,
    CP_NOTICE_NOTICE,
    CP_NOTICE_EXPERIENCEPLAN,

    CP_PERSONAL = 96,
    CP_PERSONAL_BACKGROUND,
    CP_PERSONAL_FONTS,
    CP_PERSONAL_SCREENLOCK,
    CP_PERSONAL_SCREENSAVER,
    CP_PERSONAL_THEME,
    CP_PERSONAL_DESKTOP,

    CP_UPDATE = 112,
    CP_UPDATE_BACKUP,
    CP_UPDATE_DEFENDER,
    CP_UPDATE_UPGRADE
} kdk_controlpanel_module;

typedef enum _kdk_model_type {
    MODEL_NORMAL = 0,
    MODEL_BLACKLIST,
    MODEL_WHITELIST,
} kdk_model_type;

/**
 * @brief 启用免密登录功能
 * @param username [in] 用户名
 * @return  int 返回0表示成功，其他参见错误码
 */
extern int kdk_security_enable_nopwdlogin(const char *username);

/**
 * @brief 禁用免密登录功能
 * @param username [in] 用户名
 * @return  int 返回0表示成功，其他参见错误码
 */
extern int kdk_security_disable_nopwdlogin(const char *username);

/**
 * @brief 获取免密登录功能状态
 * @param username [in] 用户名
 * @return  bool false禁用，true启用
 */
extern bool kdk_security_status_nopwdlogin(const char *username);

/**
 * @brief 启用自动登录功能
 * @param username [in] 用户名
 * @return  int 返回0表示成功，其他参见错误码
 */
extern int kdk_security_enable_autologin(const char *username);

/**
 * @brief 禁用自动登录功能
 * @param username [in] 用户名
 * @return  int 返回0表示成功，其他参见错误码
 */
extern int kdk_security_disable_autologin(const char *username);

/**
 * @brief 获取自动登录功能状态
 * @param username [in] 用户名
 * @return  bool false禁用，true启用
 */
extern bool kdk_security_status_autologin(const char *username);


#ifdef __cplusplus
}
#endif

#endif//__LIBKYDESKTOPCTRL__H__
